color_eilers_peeters <- "#f700ff"
color_platt <- "#2600ff"
color_vollenweider <- "#029b07"
color_walsby <- "#ff0000"

etr_1_type <- "etr_1"
etr_2_type <- "etr_2"

PAR_name <- "par"
prediction_name <- "prediction"

etr_label <- expression(paste("ETR [", mu, "mol electrons m"^{
    -2
} ~ "s"^{
    -1
} ~ "]"))

par_label <- expression(paste("PAR [", mu, "mol photons m"^{
    -2
} ~ "s"^{
    -1
} ~ "]"))

etr_unit_label <- expression(paste("[", mu, "mol electrons m"^{
    -2
} ~ "s"^{
    -1
} ~ "]"))
